==> apache_airflow_providers_standard-1.7.0.tar.gz: apache_airflow_providers_standard-1.7.0/src/airflow/providers/standard/exceptions.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""Exceptions used by Standard Provider."""

from __future__ import annotations

from airflow.exceptions import AirflowException


class AirflowExternalTaskSensorException(AirflowException):
    """Base exception for all ExternalTaskSensor related errors."""


class ExternalDagNotFoundError(AirflowExternalTaskSensorException):
    """Raised when the external DAG does not exist."""


class ExternalDagDeletedError(AirflowExternalTaskSensorException):
    """Raised when the external DAG was deleted."""


class ExternalTaskNotFoundError(AirflowExternalTaskSensorException):
    """Raised when the external task does not exist."""


class ExternalTaskGroupNotFoundError(AirflowExternalTaskSensorException):
    """Raised when the external task group does not exist."""


class ExternalTaskFailedError(AirflowExternalTaskSensorException):
    """Raised when the external task failed."""


class ExternalTaskGroupFailedError(AirflowExternalTaskSensorException):
    """Raised when the external task group failed."""


class ExternalDagFailedError(AirflowExternalTaskSensorException):
    """Raised when the external DAG failed."""


class DuplicateStateError(AirflowExternalTaskSensorException):
    """Raised when duplicate states are provided across allowed, skipped and failed states."""


class HITLTriggerEventError(AirflowException):
    """Raised when TriggerEvent contains error."""


class HITLTimeoutError(HITLTriggerEventError):
    """Raised when HITLOperator timeouts."""

==> apache_airflow_providers_standard-1.9.0.tar.gz: apache_airflow_providers_standard-1.9.0/src/airflow/providers/standard/exceptions.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""Exceptions used by Standard Provider."""

from __future__ import annotations

from airflow.exceptions import AirflowException


class AirflowExternalTaskSensorException(AirflowException):
    """Base exception for all ExternalTaskSensor related errors."""


class ExternalDagNotFoundError(AirflowExternalTaskSensorException):
    """Raised when the external DAG does not exist."""


class ExternalDagDeletedError(AirflowExternalTaskSensorException):
    """Raised when the external DAG was deleted."""


class ExternalTaskNotFoundError(AirflowExternalTaskSensorException):
    """Raised when the external task does not exist."""


class ExternalTaskGroupNotFoundError(AirflowExternalTaskSensorException):
    """Raised when the external task group does not exist."""


class ExternalTaskFailedError(AirflowExternalTaskSensorException):
    """Raised when the external task failed."""


class ExternalTaskGroupFailedError(AirflowExternalTaskSensorException):
    """Raised when the external task group failed."""


class ExternalDagFailedError(AirflowExternalTaskSensorException):
    """Raised when the external DAG failed."""


class DuplicateStateError(AirflowExternalTaskSensorException):
    """Raised when duplicate states are provided across allowed, skipped and failed states."""


class HITLTriggerEventError(Exception):
    """Raised when TriggerEvent contains error."""


class HITLTimeoutError(HITLTriggerEventError):
    """Raised when HITLOperator timeouts."""


class HITLRejectException(AirflowException):
    """Raised when an ApprovalOperator receives a "Reject" response when fail_on_reject is set to True."""
